@@ -8,7 +8,7 @@ use Carp qw/croak/;
 
 use HTML::TableContent::Table;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 has table => (
     is => 'rw',
@@ -65,10 +65,12 @@ sub _build_table {
   
     my $caption_spec = $self->_caption_spec;
 
-    my $cap = (keys %{ $caption_spec->[0] })[0];
-    my $caption = $table->caption($self->$cap);
-    $caption = $self->_set_inner_html('render_caption', $caption);
-    
+    if (defined $caption_spec) {
+        my $cap = (keys %{ $caption_spec->[0] })[0];
+        my $caption = $table->caption($self->$cap);
+        $caption = $self->_set_inner_html('render_caption', $caption);
+    }
+
     my $header_spec = $self->_header_spec; 
     my %row_spec = $self->_row_spec;
     my %cell_spec = $self->_cell_spec; 
@@ -321,13 +323,13 @@ HTML::TableContent::Template::Base - Base for Templates.
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
 =head1 SYNOPSIS
 
-    Package MyApp::Table::Demo;
+    package MyApp::Table::Demo;
 
     use Moo;
     use HTML::TableContent::Template;
